Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(477)

Unified Diff: sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart

Issue 145633008: Ensure that a locked git dependency is downloaded correctly. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: forgot the test Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/source/git.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart
diff --git a/sdk/lib/_internal/pub/test/get/git/lock_version_test.dart b/sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart
similarity index 81%
copy from sdk/lib/_internal/pub/test/get/git/lock_version_test.dart
copy to sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart
index 0d764576155b5a3639e47bf47d7b021edc574297..137e38414cae1301a8ae884c82c754a592299c1e 100644
--- a/sdk/lib/_internal/pub/test/get/git/lock_version_test.dart
+++ b/sdk/lib/_internal/pub/test/get/git/locked_revision_without_repo_test.dart
@@ -11,9 +11,11 @@ import '../../../lib/src/io.dart';
import '../../descriptor.dart' as d;
import '../../test_pub.dart';
+// Regression test for issue 16470.
+
main() {
initConfig();
- integration('keeps a Git package locked to the version in the lockfile', () {
+ integration('checks out the repository for a locked revision', () {
ensureGit();
d.git('foo.git', [
@@ -32,8 +34,10 @@ main() {
])
]).validate();
// Delete the packages path to simulate a new checkout of the application.
schedule(() => deleteEntry(path.join(sandboxDir, packagesPath)));
+ schedule(() => deleteEntry(path.join(sandboxDir, cachePath)));
d.git('foo.git', [
d.libDir('foo', 'foo 2'),
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/source/git.dart ('k') | no next file » | no next file with comments »
@@ -32,8 +34,10 @@ main() {
])
]).validate();
- // Delete the packages path to simulate a new checkout of the application.
+ // Delete the packages path and the cache to simulate a brand new checkout
+ // of the application.
schedule(() => deleteEntry(path.join(sandboxDir, packagesPath)));

Powered by Google App Engine
This is Rietveld 408576698